@@ -37,6 +37,7 @@ class Session:
 
     def request(self, method, service, path, *, parse=True, **kwargs):
         url = self.endpoint.resolve(service, path)
+        kwargs = filter_none_arguments(kwargs)
         res = self.http_session.request(method, url, **kwargs)
 
         if parse:
@@ -216,3 +217,20 @@ def append_credentials(credentials, context):
         credentials["cookie"] = context.get("cookie")
 
     return credentials
+
+
+#
+
+
+def filter_none_arguments(kwargs):
+    params = kwargs.get("params")
+    if isinstance(params, collections.Mapping):
+        params = {k: v for k, v in params.items() if v is not None}
+        kwargs["params"] = params
+    
+    body = kwargs.get("json")
+    if isinstance(body, collections.Mapping):
+        body = {k: v for k, v in body.items() if v is not None}
+        kwargs["json"] = body
+
+    return kwargs
\ No newline at end of file
