@@ -6,19 +6,21 @@ class SecretsClient(BaseClient):
         super().__init__(**kwargs)
 
     def list_names(self):
-        return self.session.request("get", "core", "/api/Secrets/list")
+        params = {"teamId": self.team_id}
+        return self.session.request("get", "core", "/api/Secrets/list", params=params)
 
     def fetch_value(self, name):
-        return self.session.request("get", "core", "/api/Secrets/?name={}".format(name))
+        params = {"name": name, "teamId": self.team_id}
+        return self.session.request("get", "core", "/api/Secrets/", params=params)
 
     def fetch_values(self, names):
-        body = {"names": names}
+        body = {"names": names, "teamId": self.team_id}
         return self.session.request("post", "core", "/api/Secrets/batch", json=body)
 
     def store_value(self, name, value, *, description=None):
-        body = {"name": name, "value": value, "description": description}
+        body = {"name": name, "value": value, "description": description, "teamId": self.team_id}
         return self.session.request("post", "core", "/api/Secrets/", json=body)
 
     def remove_value(self, name):
-        body = {"name": name}
+        body = {"name": name, "teamId": self.team_id}
         return self.session.request("post", "core", "/api/Secrets/remove", json=body)
